# ForkAwesome Community

This is a list of people who made this project possible, whether they contributed to FontAwesome before or to ForkAwesome since. We are trying hard to recognize all types of contributions. So if you feel you have been left out and should be mentioned here, please accept our apology and [write us a message](https://github.com/ForkAwesome/Fork-Awesome/issues/new) about it. We'll fix this as soon as possible.

## Contributors

Thanks goes to these wonderful people ([emoji key](https://github.com/kentcdodds/all-contributors#emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore -->
| [<img src="https://avatars0.githubusercontent.com/u/1076721?v=4" width="50px;" alt="Dave Gandy"/><br /><sub><b>Dave Gandy</b></sub>](https://github.com/davegandy)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=davegandy "Code") [🎨](#design-davegandy "Design") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=davegandy "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/163763?v=4" width="50px;" alt="Brian Talbot"/><br /><sub><b>Brian Talbot</b></sub>](http://www.talbs.me)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=talbs "Code") | [<img src="https://avatars1.githubusercontent.com/u/249366?v=4" width="50px;" alt="Travis Chase"/><br /><sub><b>Travis Chase</b></sub>](https://github.com/supercodepoet)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=supercodepoet "Code") | [<img src="https://avatars2.githubusercontent.com/u/132895?v=4" width="50px;" alt="Rob Madole"/><br /><sub><b>Rob Madole</b></sub>](http://robmadole.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=robmadole "Code") | [<img src="https://avatars2.githubusercontent.com/u/556268?v=4" width="50px;" alt="Geremia Taglialatela"/><br /><sub><b>Geremia Taglialatela</b></sub>](https://github.com/tagliala)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=tagliala "Documentation") [💬](#question-tagliala "Answering Questions") | [<img src="https://avatars1.githubusercontent.com/u/81942?v=4" width="50px;" alt="Mathias Bynens"/><br /><sub><b>Mathias Bynens</b></sub>](https://mathiasbynens.be/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=mathiasbynens "Code") | [<img src="https://avatars0.githubusercontent.com/u/6705160?v=4" width="50px;" alt="William Boman"/><br /><sub><b>William Boman</b></sub>](https://redwill.se/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=williamboman "Code") |
| :---: | :---: | :---: | :---: | :---: | :---: | :---: |
| [<img src="https://avatars1.githubusercontent.com/u/90316?v=4" width="50px;" alt="Matthias Kretschmann"/><br /><sub><b>Matthias Kretschmann</b></sub>](https://kretschmann.io)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=kremalicious "Code") | [<img src="https://avatars3.githubusercontent.com/u/1321596?v=4" width="50px;" alt="Maxime Fabre"/><br /><sub><b>Maxime Fabre</b></sub>](https://about.me/anahkiasen)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=Anahkiasen "Code") | [<img src="https://avatars1.githubusercontent.com/u/895831?v=4" width="50px;" alt="Patrick H. Lauke"/><br /><sub><b>Patrick H. Lauke</b></sub>](http://www.splintered.co.uk)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=patrickhlauke "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/1438457?v=4" width="50px;" alt="Dan Stroot"/><br /><sub><b>Dan Stroot</b></sub>](https://danstroot.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=dstroot "Code") | [<img src="https://avatars0.githubusercontent.com/u/29971?v=4" width="50px;" alt="Jason Porter"/><br /><sub><b>Jason Porter</b></sub>](http://lightguard-jp.blogspot.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=LightGuard "Code") | [<img src="https://avatars2.githubusercontent.com/u/1308419?v=4" width="50px;" alt="Tom Byrer"/><br /><sub><b>Tom Byrer</b></sub>](https://github.com/tomByrer)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=tomByrer "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/381393?v=4" width="50px;" alt="Gregory Koberger"/><br /><sub><b>Gregory Koberger</b></sub>](http://readme.io)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=gkoberger "Code") |
| [<img src="https://avatars1.githubusercontent.com/u/947110?v=4" width="50px;" alt="Kevin Kirsche"/><br /><sub><b>Kevin Kirsche</b></sub>](https://kevinkirsche.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=kkirsche "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/81561?v=4" width="50px;" alt="Marcus Bointon"/><br /><sub><b>Marcus Bointon</b></sub>](http://marcus.bointon.com/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=Synchro "Code") | [<img src="https://avatars2.githubusercontent.com/u/2371386?v=4" width="50px;" alt="njb_said"/><br /><sub><b>njb_said</b></sub>](https://github.com/njb-said)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=njb-said "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/953092?v=4" width="50px;" alt="AJ Acevedo"/><br /><sub><b>AJ Acevedo</b></sub>](http://ajacevedo.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=AJ-Acevedo "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/58669?v=4" width="50px;" alt="Aarni Koskela"/><br /><sub><b>Aarni Koskela</b></sub>](https://akx.github.io/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=akx "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/3806?v=4" width="50px;" alt="scudco"/><br /><sub><b>scudco</b></sub>](https://github.com/scudco)<br />[🔧](#tool-scudco "Tools") | [<img src="https://avatars1.githubusercontent.com/u/621062?v=4" width="50px;" alt="Alfio Emanuele"/><br /><sub><b>Alfio Emanuele</b></sub>](https://alfioemanuele.io)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=AlfioEmanueleFresta "Documentation") |
| [<img src="https://avatars3.githubusercontent.com/u/357623?v=4" width="50px;" alt="Andy Carter"/><br /><sub><b>Andy Carter</b></sub>](http://andy-carter.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=drmonkeyninja "Code") | [<img src="https://avatars2.githubusercontent.com/u/237005?v=4" width="50px;" alt="Andy Freeland"/><br /><sub><b>Andy Freeland</b></sub>](https://andyfreeland.net)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Arouge8 "Bug reports") [💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=rouge8 "Code") | [<img src="https://avatars1.githubusercontent.com/u/1490347?v=4" width="50px;" alt="Antério Vieira"/><br /><sub><b>Antério Vieira</b></sub>](http://owen.com.br)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=anteriovieira "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/8832594?v=4" width="50px;" alt="Ararat"/><br /><sub><b>Ararat</b></sub>](https://github.com/araratm)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=araratm "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/1879785?v=4" width="50px;" alt="Ben Gadbois"/><br /><sub><b>Ben Gadbois</b></sub>](https://github.com/bengadbois)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=bengadbois "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/216878?v=4" width="50px;" alt="Ben Thomas"/><br /><sub><b>Ben Thomas</b></sub>](https://github.com/wazoo)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=wazoo "Code") | [<img src="https://avatars0.githubusercontent.com/u/1615761?v=4" width="50px;" alt="Brad Buchanan"/><br /><sub><b>Brad Buchanan</b></sub>](http://bradleycbuchanan.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=islemaster "Documentation") |
| [<img src="https://avatars0.githubusercontent.com/u/3743423?v=4" width="50px;" alt="Brandon Sarà"/><br /><sub><b>Brandon Sarà</b></sub>](http://bsara.pro)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=bsara "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/4213522?v=4" width="50px;" alt="Bryan Channon"/><br /><sub><b>Bryan Channon</b></sub>](http://vuii.co.uk)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=Vusys "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/496987?v=4" width="50px;" alt="Cauê Thenório"/><br /><sub><b>Cauê Thenório</b></sub>](https://github.com/cauethenorio)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=cauethenorio "Code") | [<img src="https://avatars1.githubusercontent.com/u/5069304?v=4" width="50px;" alt="Chip Thien"/><br /><sub><b>Chip Thien</b></sub>](https://github.com/MacroChip)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=MacroChip "Code") | [<img src="https://avatars0.githubusercontent.com/u/610237?v=4" width="50px;" alt="Dane Hurtubise"/><br /><sub><b>Dane Hurtubise</b></sub>](http://hurtubise.me)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=hurtubise "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/59074?v=4" width="50px;" alt="Dannii Willis"/><br /><sub><b>Dannii Willis</b></sub>](https://curiousdannii.github.io/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=curiousdannii "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/32717?v=4" width="50px;" alt="Darío Hereñú"/><br /><sub><b>Darío Hereñú</b></sub>](https://github.com/kant)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=kant "Documentation") |
| [<img src="https://avatars3.githubusercontent.com/u/36873?v=4" width="50px;" alt="David Celis"/><br /><sub><b>David Celis</b></sub>](https://davidcel.is/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=davidcelis "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/207171?v=4" width="50px;" alt="Derek Myers"/><br /><sub><b>Derek Myers</b></sub>](http://derekmyers.com)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Admyers "Bug reports") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=dmyers "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/53707?v=4" width="50px;" alt="Doug Bell"/><br /><sub><b>Doug Bell</b></sub>](http://preaction.me)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=preaction "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/461752?v=4" width="50px;" alt="Eelke Blok"/><br /><sub><b>Eelke Blok</b></sub>](http://www.blokspeed.net)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=eelkeblok "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/199095?v=4" width="50px;" alt="Elan Ruusamäe"/><br /><sub><b>Elan Ruusamäe</b></sub>](https://github.com/glensc)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=glensc "Code") | [<img src="https://avatars3.githubusercontent.com/u/634191?v=4" width="50px;" alt="Eric Bailey"/><br /><sub><b>Eric Bailey</b></sub>](https://ericwbailey.design/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=ericwbailey "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/13179128?v=4" width="50px;" alt="Ferhat Elmasgüneş"/><br /><sub><b>Ferhat Elmasgüneş</b></sub>](http://ferhat.elmasgunes.net)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=ferhate "Documentation") |
| [<img src="https://avatars0.githubusercontent.com/u/100959?v=4" width="50px;" alt="Frédéric Junod"/><br /><sub><b>Frédéric Junod</b></sub>](https://github.com/fredj)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Afredj "Bug reports") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=fredj "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/2829600?v=4" width="50px;" alt="Graham Campbell"/><br /><sub><b>Graham Campbell</b></sub>](https://gjcampbell.co.uk/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=GrahamCampbell "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/1072751?v=4" width="50px;" alt="Graham Walters"/><br /><sub><b>Graham Walters</b></sub>](https://grahamwalters.me)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=GrahamWalters "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/816859?v=4" width="50px;" alt="Hendrik Kleinwaechter"/><br /><sub><b>Hendrik Kleinwaechter</b></sub>](http://www.tripl.de)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=hendricius "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/9744226?v=4" width="50px;" alt="IKOURFALN Slimane"/><br /><sub><b>IKOURFALN Slimane</b></sub>](https://github.com/ikourfaln)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Aikourfaln "Bug reports") [💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=ikourfaln "Code") | [<img src="https://avatars2.githubusercontent.com/u/141546?v=4" width="50px;" alt="Jakub Wilk"/><br /><sub><b>Jakub Wilk</b></sub>](https://github.com/jwilk)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jwilk "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/242337?v=4" width="50px;" alt="James Harrison"/><br /><sub><b>James Harrison</b></sub>](https://github.com/jjlharrison)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jjlharrison "Documentation") |
| [<img src="https://avatars3.githubusercontent.com/u/22308682?v=4" width="50px;" alt="James Johnston"/><br /><sub><b>James Johnston</b></sub>](https://github.com/james-johnston-thumbtack)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=james-johnston-thumbtack "Code") | [<img src="https://avatars2.githubusercontent.com/u/3666887?v=4" width="50px;" alt="Jan Hořava"/><br /><sub><b>Jan Hořava</b></sub>](http://honzi.cz)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=honzi "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/112170?v=4" width="50px;" alt="Jared Forsyth"/><br /><sub><b>Jared Forsyth</b></sub>](http://jaredforsyth.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jaredly "Code") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jaredly "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/8212?v=4" width="50px;" alt="Jerod Santo"/><br /><sub><b>Jerod Santo</b></sub>](https://jerodsanto.net)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jerodsanto "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/53273?v=4" width="50px;" alt="Jina Anne"/><br /><sub><b>Jina Anne</b></sub>](http://jina.me)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jina "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/429633?v=4" width="50px;" alt="JocelynDelalande"/><br /><sub><b>JocelynDelalande</b></sub>](http://jocelyn.delalande.fr)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=JocelynDelalande "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/39089?v=4" width="50px;" alt="John Hope"/><br /><sub><b>John Hope</b></sub>](http://jhope.ie)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=JonMidhir "Documentation") |
| [<img src="https://avatars1.githubusercontent.com/u/13952477?v=4" width="50px;" alt="Josh Dean"/><br /><sub><b>Josh Dean</b></sub>](https://github.com/josdea)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=josdea "Code") | [<img src="https://avatars1.githubusercontent.com/u/1188186?v=4" width="50px;" alt="Julian Krispel-Samsel"/><br /><sub><b>Julian Krispel-Samsel</b></sub>](http://reactrocket.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=juliankrispel "Code") | [<img src="https://avatars3.githubusercontent.com/u/591833?v=4" width="50px;" alt="Lee Leathers"/><br /><sub><b>Lee Leathers</b></sub>](http://about.me/leeleathers)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=theoreticaLee "Code") | [<img src="https://avatars2.githubusercontent.com/u/764854?v=4" width="50px;" alt="Leniel Macaferi"/><br /><sub><b>Leniel Macaferi</b></sub>](http://leniel.net)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=leniel "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/572289?v=4" width="50px;" alt="Mladen Đurić"/><br /><sub><b>Mladen Đurić</b></sub>](http://macmladen.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=macmladen "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/1043838?v=4" width="50px;" alt="Martin Seeler"/><br /><sub><b>Martin Seeler</b></sub>](http://www.martinseeler.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=MartinSeeler "Code") | [<img src="https://avatars2.githubusercontent.com/u/321881?v=4" width="50px;" alt="Mateusz Jagiełło"/><br /><sub><b>Mateusz Jagiełło</b></sub>](http://sigo.pl/)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Asigo "Bug reports") |
| [<img src="https://avatars3.githubusercontent.com/u/736870?v=4" width="50px;" alt="Matt Smith"/><br /><sub><b>Matt Smith</b></sub>](http://www.softwarebymatt.com)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Amtscout6 "Bug reports") | [<img src="https://avatars2.githubusercontent.com/u/495549?v=4" width="50px;" alt="Matus Gura"/><br /><sub><b>Matus Gura</b></sub>](https://github.com/gurisko)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=gurisko "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/117222?v=4" width="50px;" alt="Michael Angeles"/><br /><sub><b>Michael Angeles</b></sub>](https://github.com/jibbajabba)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jibbajabba "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/1246672?v=4" width="50px;" alt="Nielsen Ramon"/><br /><sub><b>Nielsen Ramon</b></sub>](http://nielsenramon.com/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=nielsenramon "Code") | [<img src="https://avatars1.githubusercontent.com/u/1944410?v=4" width="50px;" alt="Noah Doersing"/><br /><sub><b>Noah Doersing</b></sub>](https://hejnoah.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=doersino "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/769142?v=4" width="50px;" alt="Paul Korzhyk"/><br /><sub><b>Paul Korzhyk</b></sub>](https://github.com/paulftw)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=paulftw "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/3691490?v=4" width="50px;" alt="Peter Dave Hello"/><br /><sub><b>Peter Dave Hello</b></sub>](https://www.peterdavehello.org/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=PeterDaveHello "Documentation") [📦](#platform-PeterDaveHello "Packaging/porting to new platform") |
| [<img src="https://avatars2.githubusercontent.com/u/557895?v=4" width="50px;" alt="Peter deHaan"/><br /><sub><b>Peter deHaan</b></sub>](http://about.me/peterdehaan)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=pdehaan "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/829526?v=4" width="50px;" alt="Prayag Verma "/><br /><sub><b>Prayag Verma </b></sub>](https://www.StylifyYourBlog.com/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=pra85 "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/15367484?v=4" width="50px;" alt="ReadmeCritic"/><br /><sub><b>ReadmeCritic</b></sub>](https://twitter.com/ReadmeCritic)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=ReadmeCritic "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/1263856?v=4" width="50px;" alt="Ricardo Polo"/><br /><sub><b>Ricardo Polo</b></sub>](https://ricardopolo.co/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=ricardopolo "Code") | [<img src="https://avatars0.githubusercontent.com/u/740?v=4" width="50px;" alt="Ryan McGeary"/><br /><sub><b>Ryan McGeary</b></sub>](http://ryan.mcgeary.org)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=rmm5t "Code") | [<img src="https://avatars1.githubusercontent.com/u/125998?v=4" width="50px;" alt="Ryan Riggin"/><br /><sub><b>Ryan Riggin</b></sub>](https://github.com/rriggin)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=rriggin "Code") | [<img src="https://avatars2.githubusercontent.com/u/881590?v=4" width="50px;" alt="Ryan Senkbeil"/><br /><sub><b>Ryan Senkbeil</b></sub>](http://ryansenkbeil.com)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=rsenk330 "Code") |
| [<img src="https://avatars1.githubusercontent.com/u/1961007?v=4" width="50px;" alt="Sarang Joshi"/><br /><sub><b>Sarang Joshi</b></sub>](http://sarangjo.github.io)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=sarangjo "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/1044670?v=4" width="50px;" alt="Scott Cranfill"/><br /><sub><b>Scott Cranfill</b></sub>](https://twitter.com/scott_ish)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=Scotchester "Code") | [<img src="https://avatars1.githubusercontent.com/u/4629794?v=4" width="50px;" alt="The Jared Wilcurt"/><br /><sub><b>The Jared Wilcurt</b></sub>](http://TheJaredWilcurt.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=TheJaredWilcurt "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/308290?v=4" width="50px;" alt="Tim Guibord"/><br /><sub><b>Tim Guibord</b></sub>](https://github.com/tagCincy)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=tagCincy "Code") | [<img src="https://avatars1.githubusercontent.com/u/1152567?v=4" width="50px;" alt="Vadim Mazur"/><br /><sub><b>Vadim Mazur</b></sub>](https://github.com/mazurva)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=mazurva "Code") | [<img src="https://avatars2.githubusercontent.com/u/382608?v=4" width="50px;" alt="Vinson Chuong"/><br /><sub><b>Vinson Chuong</b></sub>](https://vinsonchuong.net)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=vinsonchuong "Code") | [<img src="https://avatars3.githubusercontent.com/u/34144858?v=4" width="50px;" alt="grvrg"/><br /><sub><b>grvrg</b></sub>](https://github.com/grvrg)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=grvrg "Documentation") |
| [<img src="https://avatars0.githubusercontent.com/u/77144?v=4" width="50px;" alt="Luca Trevisani"/><br /><sub><b>Luca Trevisani</b></sub>](https://github.com/luke83)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=luke83 "Code") | [<img src="https://avatars3.githubusercontent.com/u/1706326?v=4" width="50px;" alt="Álvaro"/><br /><sub><b>Álvaro</b></sub>](http://alvarotrigo.com)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=alvarotrigo "Documentation") | [<img src="https://avatars3.githubusercontent.com/u/192539?v=4" width="50px;" alt="Julien Deswaef"/><br /><sub><b>Julien Deswaef</b></sub>](http://xuv.be)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=xuv "Code") [🎨](#design-xuv "Design") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=xuv "Documentation") [💬](#question-xuv "Answering Questions") | [<img src="https://avatars0.githubusercontent.com/u/2192132?v=4" width="50px;" alt="n8willis"/><br /><sub><b>n8willis</b></sub>](https://github.com/n8willis)<br />[🤔](#ideas-n8willis "Ideas, Planning, & Feedback") | [<img src="https://avatars0.githubusercontent.com/u/1779453?v=4" width="50px;" alt="B. Howell"/><br /><sub><b>B. Howell</b></sub>](http://wintermute.org/brendan)<br />[🤔](#ideas-brendanhowell "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/1197187?v=4" width="50px;" alt="Algot Runeman"/><br /><sub><b>Algot Runeman</b></sub>](http://runeman.org)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=algotruneman "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/10608836?v=4" width="50px;" alt="Micah Ilbery"/><br /><sub><b>Micah Ilbery</b></sub>](https://micahilbery.com/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=micahilbery "Documentation") [🎨](#design-micahilbery "Design") |
| [<img src="https://avatars3.githubusercontent.com/u/223439?v=4" width="50px;" alt="Helmut K. C. Tessarek"/><br /><sub><b>Helmut K. C. Tessarek</b></sub>](https://evermeet.cx)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=tessus "Documentation") [💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=tessus "Code") [🎨](#design-tessus "Design") | [<img src="https://avatars0.githubusercontent.com/u/3597194?v=4" width="50px;" alt="jeromelebleu"/><br /><sub><b>jeromelebleu</b></sub>](https://github.com/jeromelebleu)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=jeromelebleu "Code") | [<img src="https://avatars3.githubusercontent.com/u/630909?v=4" width="50px;" alt="Kimberly Zick"/><br /><sub><b>Kimberly Zick</b></sub>](https://zick.kim/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=rummik "Documentation") | [<img src="https://avatars2.githubusercontent.com/u/13441278?v=4" width="50px;" alt="nIQnutn"/><br /><sub><b>nIQnutn</b></sub>](http://blog.niqnutn.com/)<br />[📝](#blog-nIQnutn "Blogposts") [🔌](#plugin-nIQnutn "Plugin/utility libraries") | [<img src="https://avatars1.githubusercontent.com/u/4307697?v=4" width="50px;" alt="Jaime Leonardo Suncin Cruz"/><br /><sub><b>Jaime Leonardo Suncin Cruz</b></sub>](https://github.com/leosuncin)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=leosuncin "Documentation") | [<img src="https://avatars0.githubusercontent.com/u/1770233?v=4" width="50px;" alt="Juliette Foucaut"/><br /><sub><b>Juliette Foucaut</b></sub>](https://www.enkisoftware.com)<br />[🔌](#plugin-juliettef "Plugin/utility libraries") | [<img src="https://avatars1.githubusercontent.com/u/6379091?v=4" width="50px;" alt="Dominik V. Salonen"/><br /><sub><b>Dominik V. Salonen</b></sub>](http://quad.moe/)<br />[📝](#blog-QuadPiece "Blogposts") |
| [<img src="https://avatars2.githubusercontent.com/u/2706882?v=4" width="50px;" alt="Alexandre Viau"/><br /><sub><b>Alexandre Viau</b></sub>](https://alexandreviau.net)<br />[🤔](#ideas-aviau "Ideas, Planning, & Feedback") [📦](#platform-aviau "Packaging/porting to new platform") | [<img src="https://avatars3.githubusercontent.com/u/7915413?v=4" width="50px;" alt="Xesau"/><br /><sub><b>Xesau</b></sub>](http://xesau.eu/)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3AXesau "Bug reports") | [<img src="https://avatars0.githubusercontent.com/u/649895?v=4" width="50px;" alt="Jan Hohner"/><br /><sub><b>Jan Hohner</b></sub>](https://janhohner.de)<br />[🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Ajanhohner "Bug reports") | [<img src="https://avatars0.githubusercontent.com/u/261579?v=4" width="50px;" alt="Dave Crossland"/><br /><sub><b>Dave Crossland</b></sub>](http://fonts.google.com)<br />[👀](#review-davelab6 "Reviewed Pull Requests") | [<img src="https://avatars0.githubusercontent.com/u/8260834?v=4" width="50px;" alt="Maximilian Berkmann"/><br /><sub><b>Maximilian Berkmann</b></sub>](http://maxcubing.wordpress.com)<br />[🤔](#ideas-Berkmann18 "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/616813?v=4" width="50px;" alt="Moritz Heiber"/><br /><sub><b>Moritz Heiber</b></sub>](https://heiber.im)<br />[🚇](#infra-moritzheiber "Infrastructure (Hosting, Build-Tools, etc)") | [<img src="https://avatars1.githubusercontent.com/u/21787?v=4" width="50px;" alt="Wesley Moore"/><br /><sub><b>Wesley Moore</b></sub>](http://www.wezm.net/)<br />[📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=wezm "Documentation") |
| [<img src="https://avatars0.githubusercontent.com/u/377632?v=4" width="50px;" alt="John Kristensen"/><br /><sub><b>John Kristensen</b></sub>](http://www.jerrykan.com/)<br />[🎨](#design-jerrykan "Design") | [<img src="https://avatars3.githubusercontent.com/u/130971?v=4" width="50px;" alt="Marco"/><br /><sub><b>Marco</b></sub>](https://amusewiki.org)<br />[🎨](#design-melmothx "Design") | [<img src="https://avatars1.githubusercontent.com/u/658496?v=4" width="50px;" alt="Jared White"/><br /><sub><b>Jared White</b></sub>](https://whitefusion.io)<br />[🖋](#content-jaredcwhite "Content") | [<img src="https://avatars2.githubusercontent.com/u/478237?v=4" width="50px;" alt="Waldir Pimenta"/><br /><sub><b>Waldir Pimenta</b></sub>](http://waldyrious.github.io)<br />[🖋](#content-waldyrious "Content") | [<img src="https://avatars3.githubusercontent.com/u/1898673?v=4" width="50px;" alt="Vladimir Anokhin"/><br /><sub><b>Vladimir Anokhin</b></sub>](https://vanokhin.com/)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=vanokhin "Code") | [<img src="https://avatars2.githubusercontent.com/u/1596934?v=4" width="50px;" alt="Maxime Lathuilière"/><br /><sub><b>Maxime Lathuilière</b></sub>](http://maxlath.eu)<br />[💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=maxlath "Code") | [<img src="https://avatars1.githubusercontent.com/u/8832594?v=4" width="50px;" alt="Ararat"/><br /><sub><b>Ararat</b></sub>](https://github.com/araratthehero)<br />[🖋](#content-araratthehero "Content") |
| [<img src="https://avatars2.githubusercontent.com/u/7890201?v=4" width="50px;" alt="Liaizon Wakest"/><br /><sub><b>Liaizon Wakest</b></sub>](http://wake.st)<br />[🤔](#ideas-wakest "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/1108409?v=4" width="50px;" alt="Ben Fedidat"/><br /><sub><b>Ben Fedidat</b></sub>](http://fedidat.com/)<br />[📝](#blog-fedidat "Blogposts") | [<img src="https://avatars0.githubusercontent.com/u/954092?v=4" width="50px;" alt="Todd Eidson"/><br /><sub><b>Todd Eidson</b></sub>](https://www.eidson.info)<br />[🤔](#ideas-eidsonator "Ideas, Planning, & Feedback") [📖](https://github.com/ForkAwesome/Fork-Awesome/commits?author=eidsonator "Documentation") [🐛](https://github.com/ForkAwesome/Fork-Awesome/issues?q=author%3Aeidsonator "Bug reports") [💻](https://github.com/ForkAwesome/Fork-Awesome/commits?author=eidsonator "Code") |
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/kentcdodds/all-contributors) specification. Contributions of any kind welcome!
